==> jaxx-runtime-2.5.30-sources.jar: jaxx/runtime/swing/renderer/ColorCellRenderer.java <==
package jaxx.runtime.swing.renderer;
/*
 * #%L
 * JAXX :: Runtime
 * $Id: ColorCellRenderer.java 2475 2012-08-08 08:50:22Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/jaxx/tags/jaxx-2.5.30/jaxx-runtime/src/main/java/jaxx/runtime/swing/renderer/ColorCellRenderer.java $
 * %%
 * Copyright (C) 2008 - 2012 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

import javax.swing.JButton;
import javax.swing.JTable;
import javax.swing.table.TableCellRenderer;
import java.awt.Color;
import java.awt.Component;

/**
 * Date: 31/07/12
 *
 * @author mallon <mallon@codelutin.com>
 * @since 2.5.4
 */
public class ColorCellRenderer implements TableCellRenderer {

    protected JButton button = new JButton();

    @Override
    public Component getTableCellRendererComponent(JTable table,
                                                   Object value,
                                                   boolean isSelected,
                                                   boolean hasFocus,
                                                   int row,
                                                   int column) {
        button.setBackground((Color) value);
        return button;
    }
}

==> jaxx-runtime-2.6-sources.jar: jaxx/runtime/swing/renderer/ColorCellRenderer.java <==
package jaxx.runtime.swing.renderer;
/*
 * #%L
 * JAXX :: Runtime
 * $Id: ColorCellRenderer.java 2475 2012-08-08 08:50:22Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/jaxx/tags/jaxx-2.6/jaxx-runtime/src/main/java/jaxx/runtime/swing/renderer/ColorCellRenderer.java $
 * %%
 * Copyright (C) 2008 - 2012 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

import javax.swing.JButton;
import javax.swing.JTable;
import javax.swing.table.TableCellRenderer;
import java.awt.Color;
import java.awt.Component;

/**
 * Date: 31/07/12
 *
 * @author mallon <mallon@codelutin.com>
 * @since 2.5.4
 */
public class ColorCellRenderer implements TableCellRenderer {

    protected JButton button = new JButton();

    @Override
    public Component getTableCellRendererComponent(JTable table,
                                                   Object value,
                                                   boolean isSelected,
                                                   boolean hasFocus,
                                                   int row,
                                                   int column) {
        button.setBackground((Color) value);
        return button;
    }
}
